@@ -167,7 +167,7 @@ TA_adjust_point_index(Recorder* recorder,
   FT_UShort i;
 
 
-  if (!glyph->num_components || !font->hint_with_components)
+  if (!glyph->num_components || !font->hint_composites)
     return idx; /* not a composite glyph */
 
   for (i = 0; i < glyph->num_pointsums; i++)
@@ -262,7 +262,7 @@ TA_sfnt_build_glyph_segments(SFNT* sfnt,
     need_words = 1;
 
   /* the number of packed segments is indicated by the function number */
-  if (recorder->glyph->num_components && font->hint_with_components)
+  if (recorder->glyph->num_components && font->hint_composites)
     *(arg--) = bci_create_segments_composite_0 + num_packed_segments;
   else
     *(arg--) = bci_create_segments_0 + num_packed_segments;
@@ -415,7 +415,7 @@ TA_sfnt_build_glyph_scaler(SFNT* sfnt,
   if (num_args > 0xFF)
     need_words = 1;
 
-  if (recorder->glyph->num_components && font->hint_with_components)
+  if (recorder->glyph->num_components && font->hint_composites)
     *(arg--) = bci_scale_composite_glyph;
   else
     *(arg--) = bci_scale_glyph;
@@ -585,8 +585,6 @@ TA_build_point_hints(Recorder* recorder,
   TA_Edge edges = axis->edges;
 
   TA_Edge edge;
-  TA_Edge before;
-  TA_Edge after;
 
   FT_Byte* p = recorder->hints_record.buf;
   FT_UShort num_edges = axis->num_edges;
@@ -767,6 +765,10 @@ TA_build_point_hints(Recorder* recorder,
          ip < ip_limit;
          ip += num_edges * num_strong_points, i++)
     {
+      TA_Edge before;
+      TA_Edge after;
+
+
       before = edges + i;
 
       j = 0;
@@ -1670,7 +1672,7 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
   load_flags = 1 << 29; /* vertical hinting only */
   if (!font->pre_hinting)
   {
-    if (font->hint_with_components)
+    if (font->hint_composites)
       load_flags |= FT_LOAD_NO_SCALE;
     else
       load_flags |= FT_LOAD_NO_RECURSE;
@@ -1705,7 +1707,7 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
 
   hints = &font->loader->hints;
 
-  /* do nothing if the setup delivered the dummy module only */
+  /* do nothing if the setup delivered the `dflt' script only */
   if (!hints->num_points)
     return FT_Err_Ok;
 
@@ -1734,8 +1736,8 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
     goto Done1;
   }
 
-  /* only scale the glyph if the dummy hinter has been used */
-  if (font->loader->metrics->clazz == &ta_dummy_script_class)
+  /* only scale the glyph if the `dflt' script has been used */
+  if (font->loader->metrics->script_class == &ta_dflt_script_class)
   {
     /* since `TA_init_recorder' hasn't been called yet, */
     /* we manually initialize the `font' and `glyph' fields */
