@@ -84,7 +84,7 @@ TA_table_build_cvt(FT_Byte** cvt,
   if (error)
     return error;
 
-  if (font->loader->hints.metrics->clazz->script == TA_SCRIPT_DUMMY)
+  if (font->loader->hints.metrics->script_class->script == TA_SCRIPT_DFLT)
   {
     haxis = NULL;
     vaxis = NULL;
@@ -198,7 +198,7 @@ FT_Error
 TA_sfnt_build_cvt_table(SFNT* sfnt,
                         FONT* font)
 {
-  FT_Error error = FT_Err_Ok;
+  FT_Error error;
 
   SFNT_Table* glyf_table = &font->tables[sfnt->glyf_idx];
   glyf_Data* data = (glyf_Data*)glyf_table->data;
