@@ -117,7 +117,7 @@ TA_glyph_parse_composite(GLYPH* glyph,
                          FT_Byte* buf,
                          FT_ULong len,
                          FT_UShort num_glyphs,
-                         FT_Bool hint_with_components)
+                         FT_Bool hint_composites)
 {
   FT_ULong flags_offset; /* after the loop, this is the offset */
                          /* to the last element in the flags array */
@@ -148,7 +148,7 @@ TA_glyph_parse_composite(GLYPH* glyph,
   /* which eventually becomes the last glyph in the `glyf' table; */
   /* for convenience, however, it is not added to the `components' array */
   /* (doing so simplifies the conversion of point indices later on) */
-  if (glyph->num_composite_contours && hint_with_components)
+  if (glyph->num_composite_contours && hint_composites)
   {
     FT_Short x_min;
     FT_Short x_max;
@@ -534,7 +534,7 @@ TA_sfnt_compute_composite_pointsums(SFNT* sfnt,
 
       glyph->num_composite_contours = num_composite_contours;
 
-      if (font->hint_with_components)
+      if (font->hint_composites)
       {
         /* update maximum values, */
         /* including the subglyphs not in `components' array */
@@ -596,7 +596,7 @@ TA_sfnt_split_glyf_table(SFNT* sfnt,
   loop_count = data->num_glyphs - 1;
 
   /* allocate one more glyph slot if we have composite glyphs */
-  if (!sfnt->max_components || !font->hint_with_components)
+  if (!sfnt->max_components || !font->hint_composites)
     data->num_glyphs -= 1;
   data->glyphs = (GLYPH*)calloc(1, data->num_glyphs * sizeof (GLYPH));
   if (!data->glyphs)
@@ -690,7 +690,7 @@ TA_sfnt_split_glyf_table(SFNT* sfnt,
     }
   }
 
-  if (sfnt->max_components && font->hint_with_components)
+  if (sfnt->max_components && font->hint_composites)
   {
     error = TA_sfnt_compute_composite_pointsums(sfnt, font);
     if (error)
@@ -757,7 +757,7 @@ TA_sfnt_split_glyf_table(SFNT* sfnt,
       if (glyph->num_contours < 0)
         error = TA_glyph_parse_composite(glyph, buf, len,
                                          data->num_glyphs,
-                                         font->hint_with_components);
+                                         font->hint_composites);
       else
         error = TA_glyph_parse_simple(glyph, buf, len);
       if (error)
@@ -765,7 +765,7 @@ TA_sfnt_split_glyf_table(SFNT* sfnt,
     }
   }
 
-  if (sfnt->max_components && font->hint_with_components)
+  if (sfnt->max_components && font->hint_composites)
   {
     /* construct and append our special glyph used as a composite element */
     GLYPH* glyph = &data->glyphs[data->num_glyphs - 1];
