@@ -62,13 +62,14 @@ ta_latin_metrics_init_widths(TA_LatinMetrics metrics,
     TA_Scaler scaler = &dummy->root.scaler;
 
 
-    glyph_index = FT_Get_Char_Index(face,
-                                    metrics->root.clazz->standard_char);
+    glyph_index = FT_Get_Char_Index(
+                    face,
+                    metrics->root.script_class->standard_char);
     if (glyph_index == 0)
       goto Exit;
 
     TA_LOG(("standard character: 0x%X (glyph index %d)\n",
-            metrics->root.clazz->standard_char, glyph_index));
+            metrics->root.script_class->standard_char, glyph_index));
 
     error = FT_Load_Glyph(face, glyph_index, FT_LOAD_NO_SCALE);
     if (error || face->glyph->outline.n_points <= 0)
@@ -316,10 +317,14 @@ ta_latin_metrics_init_blues(TA_LatinMetrics metrics,
       {
         FT_Pos best_x = points[best_point].x;
         FT_Int prev, next;
+        FT_Int best_segment_first, best_segment_last;
         FT_Int best_on_point_first, best_on_point_last;
         FT_Pos dist;
 
 
+        best_segment_first = best_point;
+        best_segment_last = best_point;
+
         if (FT_CURVE_TAG(outline.tags[best_point]) == FT_CURVE_TAG_ON)
         {
           best_on_point_first = best_point;
@@ -331,8 +336,9 @@ ta_latin_metrics_init_blues(TA_LatinMetrics metrics,
           best_on_point_last = -1;
         }
 
-        /* look for the previous and next points that are not on the */
-        /* same Y coordinate, then threshold the `closeness'... */
+        /* look for the previous and next points on the contour */
+        /* that are not on the same Y coordinate, then threshold */
+        /* the `closeness'... */
         prev = best_point;
         next = prev;
 
@@ -345,11 +351,13 @@ ta_latin_metrics_init_blues(TA_LatinMetrics metrics,
 
           dist = TA_ABS(points[prev].y - best_y);
           /* accept a small distance or a small angle (both values are */
-          /* heuristic; value 20 corresponds to approx. 2.9 degrees)   */
+          /* heuristic; value 20 corresponds to approx. 2.9 degrees) */
           if (dist > 5)
             if (TA_ABS(points[prev].x - best_x) <= 20 * dist)
               break;
 
+          best_segment_first = prev;
+
           if (FT_CURVE_TAG(outline.tags[prev]) == FT_CURVE_TAG_ON)
           {
             best_on_point_first = prev;
@@ -371,6 +379,8 @@ ta_latin_metrics_init_blues(TA_LatinMetrics metrics,
             if (TA_ABS(points[next].x - best_x) <= 20 * dist)
               break;
 
+          best_segment_last = next;
+
           if (FT_CURVE_TAG(outline.tags[next]) == FT_CURVE_TAG_ON)
           {
             best_on_point_last = next;
@@ -380,8 +390,16 @@ ta_latin_metrics_init_blues(TA_LatinMetrics metrics,
 
         } while (next != best_point);
 
-        /* now set the `round' flag depending on the segment's kind */
-        /* (value 8 is heuristic) */
+        /*
+         * now set the `round' flag depending on the segment's kind:
+         *
+         * - if the horizontal distance between the first and last
+         *   `on' point is larger than upem/8 (value 8 is heuristic)
+         *   we have a flat segment
+         * - if either the first or the last point of the segment is
+         *   an `off' point, the segment is round, otherwise it is
+         *   flat
+         */
         if (best_on_point_first >= 0
             && best_on_point_last >= 0
             && (FT_UInt)(TA_ABS(points[best_on_point_last].x
@@ -389,9 +407,10 @@ ta_latin_metrics_init_blues(TA_LatinMetrics metrics,
                  > metrics->units_per_em / 8)
           round = 0;
         else
-          round = FT_BOOL(
-            FT_CURVE_TAG(outline.tags[prev]) != FT_CURVE_TAG_ON
-            || FT_CURVE_TAG(outline.tags[next]) != FT_CURVE_TAG_ON);
+          round = FT_BOOL(FT_CURVE_TAG(outline.tags[best_segment_first])
+                            != FT_CURVE_TAG_ON
+                          || FT_CURVE_TAG(outline.tags[best_segment_last])
+                               != FT_CURVE_TAG_ON);
 
         TA_LOG((" (%s)\n", round ? "round" : "flat"));
       }
@@ -764,7 +783,7 @@ ta_latin_metrics_scale_dim(TA_LatinMetrics metrics,
 
         if (delta2 < 32)
           delta2 = 0;
-        else if (delta < 48)
+        else if (delta2 < 48)
           delta2 = 32;
         else
           delta2 = 64;
@@ -2529,10 +2548,25 @@ Exit:
 }
 
 
+const TA_WritingSystemClassRec ta_latin_writing_system_class =
+{
+  TA_WRITING_SYSTEM_LATIN,
+
+  sizeof (TA_LatinMetricsRec),
+
+  (TA_Script_InitMetricsFunc)ta_latin_metrics_init,
+  (TA_Script_ScaleMetricsFunc)ta_latin_metrics_scale,
+  (TA_Script_DoneMetricsFunc)NULL,
+
+  (TA_Script_InitHintsFunc)ta_latin_hints_init,
+  (TA_Script_ApplyHintsFunc)ta_latin_hints_apply
+};
+
+
 /* XXX: this should probably fine tuned to differentiate better between */
 /* scripts... */
 
-static const TA_Script_UniRangeRec ta_latin_uniranges[] =
+static const TA_Script_UniRangeRec ta_latn_uniranges[] =
 {
   TA_UNIRANGE_REC(0x0020UL, 0x007FUL), /* Basic Latin (no control chars) */
   TA_UNIRANGE_REC(0x00A0UL, 0x00FFUL), /* Latin-1 Supplement (no control chars) */
@@ -2566,20 +2600,13 @@ static const TA_Script_UniRangeRec ta_latin_uniranges[] =
 };
 
 
-const TA_ScriptClassRec ta_latin_script_class =
+const TA_ScriptClassRec ta_latn_script_class =
 {
-  TA_SCRIPT_LATIN,
-  ta_latin_uniranges,
-  'o',
+  TA_SCRIPT_LATN,
+  TA_WRITING_SYSTEM_LATIN,
 
-  sizeof (TA_LatinMetricsRec),
-
-  (TA_Script_InitMetricsFunc)ta_latin_metrics_init,
-  (TA_Script_ScaleMetricsFunc)ta_latin_metrics_scale,
-  (TA_Script_DoneMetricsFunc)NULL,
-
-  (TA_Script_InitHintsFunc)ta_latin_hints_init,
-  (TA_Script_ApplyHintsFunc)ta_latin_hints_apply
+  ta_latn_uniranges,
+  'o'
 };
 
 /* end of talatin.c */
