@@ -575,7 +575,7 @@ TA_table_build_prep(FT_Byte** prep,
   FT_Byte* buf_p = NULL;
 
 
-  if (font->loader->hints.metrics->clazz->script == TA_SCRIPT_NONE)
+  if (font->loader->hints.metrics->script_class->script == TA_SCRIPT_NONE)
     vaxis = NULL;
   else
   {
@@ -753,7 +753,7 @@ FT_Error
 TA_sfnt_build_prep_table(SFNT* sfnt,
                          FONT* font)
 {
-  FT_Error error = FT_Err_Ok;
+  FT_Error error;
 
   SFNT_Table* glyf_table = &font->tables[sfnt->glyf_idx];
   glyf_Data* data = (glyf_Data*)glyf_table->data;
